@@ -3,6 +3,7 @@
 
 package org.torproject.descriptor;
 
+import java.io.Serializable;
 import java.util.List;
 import java.util.Set;
 import java.util.SortedMap;
@@ -23,7 +24,7 @@ import java.util.SortedSet;
  *
  * @since 1.0.0
  */
-public interface NetworkStatusEntry {
+public interface NetworkStatusEntry extends Serializable {
 
   /**
    * Return the raw network status entry bytes.
@@ -131,6 +132,14 @@ public interface NetworkStatusEntry {
    */
   SortedMap<String, SortedSet<Long>> getProtocols();
 
+  /**
+   * Return the various statistics that an authority has computed for
+   * this relay. Each stats is represented as a key + value.
+   *
+   * @since 2.20.0
+   */
+  SortedMap<String, Double> getStats();
+
   /**
    * Return the bandwidth weight of this server or -1 if the status entry
    * didn't contain a bandwidth line.
@@ -182,5 +191,12 @@ public interface NetworkStatusEntry {
    * @since 1.1.0
    */
   String getMasterKeyEd25519();
-}
 
+  /**
+   * Return the server's supported consensus methods, or null if the status
+   * entry didn't contain this information or if the status is not a vote.
+   *
+   * @since 1.2.20
+   */
+  String getSupportedConsensusMethods();
+}
